=======
History
=======

0.2.3 (2020-10-01)
------------------

- Add missing node check in account import check
- Rename :code:`AccountImport` to :code:`GethAccountImport` as it's node-specific


0.2.0 (2020-07-13)
------------------

- First release on PyPI.
